DataFormat

Enum DataFormat 

#[repr(u8)]
pub enum DataFormat { Intensity4 = 0, Intensity8 = 1, IntensityA4 = 2, IntensityA8 = 3, Rgb565 = 4, Rgb5a3 = 5, Argb8888 = 6, Index4 = 8, Index8 = 9, Dxt1 = 14, }
This enum specifies the format for which a GVR texture should be encoded in.

Most formats are to be used in accordance with crate::TextureEncoder::new_gcix() or crate::TextureEncoder::new_gbix(). If you wish to use DataFormat::Index4 or DataFormat::Index8, then use crate::TextureEncoder::new_gcix_palettized() or crate::TextureEncoder::new_gbix_palettized(). That way you can specify the color format for the color palette alongside the data format.

Variants



Intensity4 = 0

Stores 4-bit intensity values (each pixel is composed of just one value). This makes the image look grayscale. This format stores no alpha channel.



Intensity8 = 1

Stores 8-bit intensity values (each pixel is composed of just one value). This makes the image look grayscale. This format stores no alpha channel.



IntensityA4 = 2

Stores 4-bit intensity values (each pixel is composed of just one value) along with an alpha channel. This makes the image look grayscale.



IntensityA8 = 3

Stores 8-bit intensity values (each pixel is composed of just one value) along with an alpha channel. This makes the image look grayscale.



Rgb565 = 4

Stores 16-bit color values, but does not save an alpha channel.



Rgb5a3 = 5

Stores 16-bit color values, but saves the alpha channel as well.



Argb8888 = 6

Stores 24-bit depth true color (1 byte per color). It also stores an 8-bit alpha channel.

This format is by far the one with the largest filesize, although the most accurate in terms of color.



Index4 = 8

Stores 4-bit indices into a quantized color palette.

The color palette can only encode a maximum of 16 colors, which means images with a larger variety of colors will not look that great.



Index8 = 9

Stores 8-bit indices into a quantized color palette.

The color palette can encode a maximum of 256 colors, which means images preserve a decent amount of their color quality, as opposed to the DataFormat::Index4 format.



Dxt1 = 14

Encodes the image using a DXT1 compression algorithm, also known as BC1 (Block Compression 1).

Works well in environments where the texture cannot be easily viewed (like a 3D model in motion), but not that well in other cases (like on a 2D menu), as the compression artifacts can be quite visible at times.